==> core_models-0.1.0.gem: config/initializers/crud.rb <==
if Gem.loaded_specs.keys.include?('crud')

  # Code extensions
  module Crud
  end

  # Initialisation
  Crud.setup do |config|
    # Set model path
    config.model_path << File.join(::CoreModels::Engine.root, 'app', 'models')

    # Custom fields
    config.custom_fields << {
      :class => '::CoreModels::Base::Colour',
      :only => [:index, :show],
      :column_name => 'colour_code',
      :partial => 'core_models/partials/colour_display', :record_data_parameter => 'colour'
    }

    config.custom_fields << {
      :class => '::CoreModels::Base::Address',
      :only => [:index],
      :global => true,
      :partial => 'core_models/base/addresses/gmaps_addresses', :record_data_parameter => 'addresses'
    }

    config.custom_fields << {
      :class => '::CoreModels::Base::Address',
      :only => [:show],
      :global => true,
      :partial => 'core_models/base/addresses/gmaps_address', :record_data_parameter => 'address'
    }

    config.custom_fields << {
      :class => '::CoreModels::PeopleAndCompanies::Person',
      :only => [:index],
      :column_name => 'photo',
      :column_replacement => true,
      :partial => 'asset_management/partials/preview', :record_data_parameter => 'asset_data',
      :additional_partial_parameters => {:size => '50x50'}
    }

    config.custom_fields << {
      :class => '::CoreModels::PeopleAndCompanies::Person',
      :only => [:show],
      :column_name => 'photo',
      :column_replacement => true,
      :partial => 'asset_management/partials/photo', :record_data_parameter => 'asset_data',
      :additional_partial_parameters => {:size => '200x400'}
    }

    config.custom_fields << {
      :class => '::CoreModels::PeopleAndCompanies::Person',
      :only => [:new, :edit],
      :column_name => 'photo',
      :column_replacement => true,
      :partial => 'asset_management/partials/photo_form', :record_data_parameter => 'f'
    }
  end

end

==> core_models-0.2.9.gem: config/initializers/crud.rb <==
if Gem.loaded_specs.keys.include?('crud')

  # Code extensions
  module Crud
  end

  # Initialisation
  Crud.setup do |config|
    # Set model path
    config.model_path << File.join(::CoreModels::Engine.root, 'app', 'models')

    # Custom fields
    config.custom_fields << {
      :class => '::CoreModels::Base::Colour',
      :only => [:index, :show],
      :column_name => 'colour_code',
      :partial => 'core_models/partials/colour_display', :record_data_parameter => 'colour'
    }

    config.custom_fields << {
      :class => '::CoreModels::Base::Address',
      :only => [:index],
      :global => true,
      :partial => 'core_models/base/addresses/gmaps_addresses', :record_data_parameter => 'addresses'
    }

    config.custom_fields << {
      :class => '::CoreModels::Base::Address',
      :only => [:show],
      :global => true,
      :partial => 'core_models/base/addresses/gmaps_address', :record_data_parameter => 'address'
    }

    config.custom_fields << {
      :class => '::CoreModels::PeopleAndCompanies::Person',
      :only => [:index],
      :column_name => 'photo',
      :column_replacement => true,
      :partial => 'asset_management/partials/preview', :record_data_parameter => 'asset_data',
      :additional_partial_parameters => {:size => '50x50'}
    }

    config.custom_fields << {
      :class => '::CoreModels::PeopleAndCompanies::Person',
      :only => [:show],
      :column_name => 'photo',
      :column_replacement => true,
      :partial => 'asset_management/partials/photo', :record_data_parameter => 'asset_data',
      :additional_partial_parameters => {:size => '200x400'}
    }

    config.custom_fields << {
      :class => '::CoreModels::PeopleAndCompanies::Person',
      :only => [:new, :edit],
      :column_name => 'photo',
      :column_replacement => true,
      :partial => 'asset_management/partials/photo', :record_data_parameter => 'f'
    }
  end

end
